@@ -5,7 +5,8 @@ from cubicweb.devtools.testlib import AutomaticWebTest
 class AutomaticWebTest(AutomaticWebTest):
 
     def to_test_etypes(self):
-        return set(('Expense', 'ExpenseLine', 'PaidByAccount', 'PaidForAccount', 'Refund'))
+        return set(('Expense', 'ExpenseLine', 'Refund',
+                    'PaidByAccount', 'PaidForAccount'))
 
     def list_startup_views(self):
         return ()
